module HearthstoneCardApi
  class Data
    attr_reader :format, :data, :objs

    def initialize(api_response)
      @objs = []
      @data = api_response
      @format = HearthstoneCardApi.data_format
    end

    def formatted
      return self.send("return_#{format}", data)
    end

    private
      def return_objects(d)
        data = d.body
        if data.is_a? Hash
          if data.key?("error") or data.key?("patch")
            return data
          else
            data.each_pair do |key,value|
              data_to_objects(value)
            end
          end
        elsif data.is_a? Array
          data_to_objects(data)
        end
        return objs
      end
      
      def return_json(data)
        json = data.raw_body
        return json
      end

      def return_hash(data)
        hashes = data.body
        return hashes
      end
      
      def data_to_objects(hash)
        hash.each do |a|
          b = Hash[a.map{|(k,v)| [underscore(k).to_sym, v]}] 
          obj = Struct.new(*b.keys).new(*b.values)
          objs.push(obj)
        end
        return objs
      end

      def underscore(string)
        string.gsub(/::/, '/').
        gsub(/([A-Z]+)([A-Z][a-z])/,'\1_\2').
        gsub(/([a-z\d])([A-Z])/,'\1_\2').
        tr("-", "_").
        downcase
      end
  end
end
